@@ -374,6 +374,7 @@ _upterm_help()
     flags_with_completion=()
     flags_completion=()
 
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -411,6 +412,7 @@ _upterm_host()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--hide-client-ip")
     flags+=("--known-hosts=")
     two_word_flags+=("--known-hosts")
     flags+=("--private-key=")
@@ -422,6 +424,7 @@ _upterm_host()
     two_word_flags+=("--server")
     flags+=("--srht-user=")
     two_word_flags+=("--srht-user")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -446,6 +449,7 @@ _upterm_proxy()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -472,6 +476,9 @@ _upterm_session_current()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--hide-client-ip")
+    local_nonpersistent_flags+=("--hide-client-ip")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -492,6 +499,7 @@ _upterm_session_help()
     flags_with_completion=()
     flags_completion=()
 
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -517,6 +525,9 @@ _upterm_session_info()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--hide-client-ip")
+    local_nonpersistent_flags+=("--hide-client-ip")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -541,6 +552,7 @@ _upterm_session_list()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -583,6 +595,7 @@ _upterm_session()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -607,6 +620,7 @@ _upterm_upgrade()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -631,6 +645,7 @@ _upterm_version()
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
     local_nonpersistent_flags+=("-h")
+    flags+=("--debug")
 
     must_have_one_flag=()
     must_have_one_noun=()
@@ -661,6 +676,7 @@ _upterm_root_command()
     flags_with_completion=()
     flags_completion=()
 
+    flags+=("--debug")
     flags+=("--help")
     flags+=("-h")
     local_nonpersistent_flags+=("--help")
